@@ -32,7 +32,7 @@ from time import time
 from parso import parse
 from parso.python.tree import Name, Number, Keyword
 
-__version__ = '2.1.0'
+__version__ = '2.2.0'
 
 
 try:
@@ -236,7 +236,7 @@ def number_mutation(value, **_):
 
 
 def string_mutation(value, **_):
-    prefix = value[:min([x for x in [value.find('"'), value.find("'")] if x != -1])]
+    prefix = value[:min(x for x in [value.find('"'), value.find("'")] if x != -1)]
     value = value[len(prefix):]
 
     if value.startswith('"""') or value.startswith("'''"):
@@ -267,7 +267,10 @@ NEWLINE = {'formatting': [], 'indent': '', 'type': 'endl', 'value': ''}
 
 
 def argument_mutation(children, context, **_):
-    """
+    """Mutate the arguments one by one from dict(a=b) to dict(aXXX=b).
+
+    This is similar to the mutation of dict literals in the form {'a': b}.
+
     :type context: Context
     """
     if len(context.stack) >= 3 and context.stack[-3].type in ('power', 'atom_expr'):
@@ -802,7 +805,7 @@ class Config(object):
                  baseline_time_elapsed, test_time_multiplier, test_time_base,
                  backup, dict_synonyms, total, using_testmon, cache_only,
                  tests_dirs, hash_of_tests, pre_mutation, post_mutation,
-                 coverage_data, paths_to_mutate):
+                 coverage_data, paths_to_mutate, no_progress):
         self.swallow_output = swallow_output
         self.test_command = test_command
         self.covered_lines_by_filename = covered_lines_by_filename
@@ -820,6 +823,7 @@ class Config(object):
         self.pre_mutation = pre_mutation
         self.coverage_data = coverage_data
         self.paths_to_mutate = paths_to_mutate
+        self.no_progress = no_progress
 
 
 def tests_pass(config: Config, callback) -> bool:
@@ -836,7 +840,7 @@ def tests_pass(config: Config, callback) -> bool:
         return hammett_tests_pass(config, callback)
 
     returncode = popen_streaming_output(config.test_command, callback, timeout=config.baseline_time_elapsed * 10)
-    return returncode == 0 or (config.using_testmon and returncode == 5)
+    return returncode != 1
 
 
 def config_from_setup_cfg(**defaults):
@@ -907,8 +911,9 @@ def guess_paths_to_mutate():
 
 
 class Progress(object):
-    def __init__(self, total):
+    def __init__(self, total, output_legend):
         self.total = total
+        self.output_legend = output_legend
         self.progress = 0
         self.skipped = 0
         self.killed_mutants = 0
@@ -917,7 +922,20 @@ class Progress(object):
         self.suspicious_mutants = 0
 
     def print(self):
-        print_status('{}/{}  🎉 {}  ⏰ {}  🤔 {}  🙁 {}  🔇 {}'.format(self.progress, self.total, self.killed_mutants, self.surviving_mutants_timeout, self.suspicious_mutants, self.surviving_mutants, self.skipped))
+        print_status('{}/{}  {} {}  {} {}  {} {}  {} {}  {} {}'.format(
+            self.progress,
+            self.total,
+            self.output_legend["killed"],
+            self.killed_mutants,
+            self.output_legend["timeout"],
+            self.surviving_mutants_timeout,
+            self.output_legend["suspicious"],
+            self.suspicious_mutants,
+            self.output_legend["survived"],
+            self.surviving_mutants,
+            self.output_legend["skipped"],
+            self.skipped)
+        )
 
     def register(self, status):
         if status == BAD_SURVIVED:
@@ -1011,7 +1029,7 @@ def popen_streaming_output(cmd, callback, timeout=None):
                     if not line:
                         break
                     callback(line)
-        except (IOError, OSError):
+        except OSError:
             # This seems to happen on some platforms, including TravisCI.
             # It seems like it's ok to just let this pass here, you just
             # won't get as nice feedback.
@@ -1073,7 +1091,7 @@ def hammett_tests_pass(config, callback):
 
     modules_to_force_unload = {x.partition(os.sep)[0].replace('.py', '') for x in config.paths_to_mutate}
 
-    for module_name in list(sorted(set(sys.modules.keys()) - set(modules_before), reverse=True)):
+    for module_name in sorted(set(sys.modules.keys()) - set(modules_before), reverse=True):
         if any(module_name.startswith(x) for x in modules_to_force_unload) or module_name.startswith('tests') or module_name.startswith('django'):
             del sys.modules[module_name]
 
@@ -1137,7 +1155,7 @@ def run_mutation_tests(config, progress, mutations_by_file):
         elif command == 'progress':
             if not config.swallow_output:
                 print(status, end='', flush=True)
-            else:
+            elif not config.no_progress:
                 progress.print()
 
         else:
@@ -1147,8 +1165,6 @@ def run_mutation_tests(config, progress, mutations_by_file):
 
             update_mutant_status(file_to_mutate=filename, mutation_id=mutation_id, status=status, tests_hash=config.hash_of_tests)
 
-            progress.print()
-
 
 def read_coverage_data():
     """
